@@ -11,23 +11,23 @@
 /* Name of this program.  */
 GLOBAL const char *program_name;
 
-/* Boolean: iff true warn about packages which are older on the ftp site than the version installed */
-GLOBAL int warn_older;
+/* If true warn about packages which are older on the ftp site than the version installed */
+GLOBAL boolean warn_older;
 
 /* Debug level */
 GLOBAL unsigned long debug_level;
 
-/* Visible warnings level */
-GLOBAL signed long visible_warn_level;
-
 /* The secondary architecture's name */
-GLOBAL char secondary_architecture[PACKAGE_NAME_LENGTH];
+GLOBAL char *packages_architecture;
+
+/* As above with a space prepended for matching */
+GLOBAL char *binary_architecture_match;
 
 /* The filename for the Packages-arch-specific file */
-GLOBAL char packages_arch_specific_filename[PACKAGE_NAME_LENGTH];
+GLOBAL char *packages_arch_specific_filename;
 
 /* The filename for the Packages-arch-specific file */
-GLOBAL char packages_source_filename[PACKAGE_NAME_LENGTH];
+GLOBAL char *packages_source_filename;
 
 /* Output format */
 GLOBAL int output_format;
