@@ -1,5 +1,5 @@
-/* Quinn Diff, Compares two Packages files looking for differences between Archs */
-/* Copyright (C) 1997-1998, James Troup <james@nocrew.org> */
+/* Quinn Diff, Determine which packages need recompiled for any given architecture */
+/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,14 +19,18 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "config.h"
 #include "common.h"
+#include "config.h"
 #include "error.h"
 #include "getopt.h"
 #include "init.h"
+#include "parse_packages.h"
+#include "parse_sources.h"
+#include "utils.h"
+#include "xmalloc.h"
 
 void 
-parse_opt (int argc, char **argv, primary_package_info *primary, secondary_package_info *secondary)
+parse_opt (int argc, char **argv, sources_info *sources, packages_info *packages)
 {
   char *debug_argument;
   int c;
@@ -39,16 +43,14 @@ parse_opt (int argc, char **argv, primary_package_info *primary, secondary_packa
 	{"arch-specific-packages", required_argument, NULL, 'a'},
 	{"debug", required_argument, NULL, 'D'},
 	{"help", no_argument, NULL, 'h'},
-	{"primary-packages", required_argument, NULL, 'p'},
-	{"secondary-packages", required_argument, NULL, 's'},
-	{"source-packages", required_argument, NULL, 'o'}, 
+	{"sources", required_argument, NULL, 's'},
+	{"packages", required_argument, NULL, 'p'},
 	{"version", no_argument, NULL, 'V'},
-	{"visible-warn", required_argument, NULL, 'w'}, 
-	{"warn-older", no_argument, &warn_older, 1},
+	{"warn-older", no_argument, NULL, 'w'},
 	{0, 0, 0, 0}
       };
 
-      c = getopt_long (argc, argv, "a:D:o:p:s:w:hV",
+      c = getopt_long (argc, argv, "a:D:p:s:w:hV",
 		       long_options, &option_index);
       if (c == EOF)
 	break;
@@ -56,7 +58,8 @@ parse_opt (int argc, char **argv, primary_package_info *primary, secondary_packa
       switch (c)
 	{
 	case 'a':
-	  strncpy (packages_arch_specific_filename, optarg, PACKAGE_NAME_LENGTH);
+	  xfree_if_non_null (packages_arch_specific_filename);
+	  packages_arch_specific_filename = xstrdup (optarg);
 	  break;
 
 	case 'D':
@@ -77,25 +80,18 @@ parse_opt (int argc, char **argv, primary_package_info *primary, secondary_packa
 	  usage (0);
 	  break;
 
-	case 'o': 
-	  strncpy (packages_source_filename, optarg, PACKAGE_NAME_LENGTH);
-	  break;
-
 	case 'p':
-	  strncpy (primary->file_name, optarg, PACKAGE_NAME_LENGTH);
+	  xfree_if_non_null (packages->file_name);
+	  packages->file_name = xstrdup (optarg);
 	  break;
 
 	case 's':
-	  strncpy (secondary->file_name, optarg, PACKAGE_NAME_LENGTH);
+	  xfree_if_non_null (sources->file_name);
+	  sources->file_name = xstrdup (optarg);
 	  break;
 
 	case 'w':
-	  visible_warn_level = strtoul (optarg, &debug_argument, 8);
-	  if (*debug_argument)
-	    {
-	      error ("-w/--visible-warn requires an octal argument");
-	      usage (1);
-	    }
+	  warn_older = TRUE;
 	  break;
 
 	case 'V':
@@ -123,20 +119,17 @@ parse_opt (int argc, char **argv, primary_package_info *primary, secondary_packa
 void
 usage (int status)
 {
-  fprintf (status ? stderr : stdout, "Usage: %s [-dapshV]\n\
+  fprintf (status ? stderr : stdout, "Usage: %s [-apswhDV]\n\
 -a --arch-specific-packages  filename of Packages-arch-specific file.\n\
-                              default: Packages-arch-specific in cwd\n\
+                              default: /etc/Packages-arch-specific\n\
 -D --debug=<octal value>     enable debug output; see -Dhelp or --debug=help\n\
 -h --help                    give this help\n\
--o --source-packages         filename of source Packages file.\n\
--p --primary-packages        filename of primary architectures' Packages file.\n\
-                              default: Packages-primary in cwd\n\
--s --secondary-packages      filename of secondary architectures' Packages file.\n\
-                              default: Packages-sceondary in cwd\n\
--V --version                 display version number\n\
--w --visible-warn=<octal value> show packages which are consider erroneous.\n\
-   --warn-older              warn about packages older on primary\n", program_name);
-
+-p --packages                filename of Packages file.\n\
+                              default: Packages in cwd\n\n
+-s --source-packages        filename of Sources file.\n\
+                              default: Sources in cwd\n\
+-w --warn-older              warn about packages older on primary\n\
+-V --version                 display version number\n", program_name);
   exit (status);
 
 }
