@@ -1,5 +1,5 @@
-/* Quinn Diff, Compares two Packages files looking for differences between Archs */
-/* Copyright (C) 1998, James Troup <james@nocrew.org> */
+/* Quinn Diff, Determine which packages need recompiled for any given architecture */
+/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,6 +29,15 @@ struct _quinn_list
   Qlist *next;
 };
 
+typedef struct _want_node want_node;
+
+struct _want_node 
+{
+  char search_string[20];
+  char **destination_string;
+  boolean found;
+};
+
 /****** Non-Generic *********/
 Qlist *want_append(Qlist *list, want_node *data);
 Qlist *want_find(Qlist *list, const char *search_string);
