@@ -1,5 +1,5 @@
-/* Quinn Diff, Compares two Packages files looking for differences between Archs */
-/* Copyright (C) 1997-1998, James Troup <james@nocrew.org> */
+/* Quinn Diff, Determine which packages need recompiled for any given architecture */
+/* Copyright (C) 1997-1999, James Troup <james@nocrew.org> */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,16 +16,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef MAIN_H
-#define MAIN_H
+#ifndef __MAIN_H__
+#define __MAIN_H__
 
 #include <stdio.h>
 
-#define PACKAGE_NAME_LENGTH 400  /* This really does suck something chronic, there has to be a better way */
-
-#define DBG_SHOW_OLDER   0x0001
-#define DBG_LEVEL_1      0x0002
-
 typedef int   boolean;  /* Should this be char?  Who knows?  Who cares? */
 
 #ifndef FALSE
@@ -36,25 +31,4 @@ typedef int   boolean;  /* Should this be char?  Who knows?  Who cares? */
 #define TRUE 1
 #endif /* TRUE */
 
-typedef struct _secondary_package_info secondary_package_info;
-
-struct _secondary_package_info {
-  char file_name[PACKAGE_NAME_LENGTH];
-  FILE *file_pointer;
-  long file_length;
-  char *buffer;		
-  int buffer_pos;
-  char name[PACKAGE_NAME_LENGTH];   
-  char version[PACKAGE_NAME_LENGTH];
-};
-
-typedef struct _want_node want_node;
-
-struct _want_node 
-{
-  char search_string[20];
-  char *destination_string;
-  boolean found;
-};
-
-#endif /* MAIN_H */
+#endif /* __MAIN_H__ */
